@@ -50,7 +50,7 @@ class TestFlavor(base.TestCase):
                     self.operator_cloud.delete_flavor(f['id'])
                 except Exception as e:
                     # We were unable to delete a flavor, let's try with next
-                    exception_list.append(e)
+                    exception_list.append(str(e))
                     continue
         if exception_list:
             # Raise an error: we must make users aware that something went
