@@ -15,9 +15,11 @@ import tempfile
 
 import mock
 import os_client_config as occ
+import testtools
 import yaml
 
 import shade
+from shade import exc
 from shade import meta
 from shade.tests import fakes
 from shade.tests.unit import base
@@ -259,7 +261,8 @@ class TestMemoryCache(base.TestCase):
         imagefile.write(b'\0')
         imagefile.close()
         self.cloud.create_image(
-            name, imagefile.name, container=container, wait=True)
+            name, imagefile.name, container=container, wait=True,
+            is_public=False)
 
     @mock.patch.object(occ.cloud_config.CloudConfig, 'get_api_version')
     @mock.patch.object(shade.OpenStackCloud, 'glance_client')
@@ -273,8 +276,10 @@ class TestMemoryCache(base.TestCase):
         glance_mock.images.list.return_value = [fake_image]
         self._call_create_image('42 name')
         args = {'name': '42 name',
+                'container_format': 'bare', 'disk_format': 'qcow2',
                 'properties': {'owner_specified.shade.md5': mock.ANY,
-                               'owner_specified.shade.sha256': mock.ANY}}
+                               'owner_specified.shade.sha256': mock.ANY,
+                               'is_public': False}}
         glance_mock.images.create.assert_called_with(**args)
         glance_mock.images.update.assert_called_with(data=mock.ANY,
                                                      image=fake_image)
@@ -295,11 +300,13 @@ class TestMemoryCache(base.TestCase):
         glance_mock.images.list.return_value = [fake_image]
         self._call_create_image('42 name')
         args = {'name': '42 name',
+                'container_format': 'bare', 'disk_format': 'qcow2',
                 'owner_specified.shade.md5': mock.ANY,
-                'owner_specified.shade.sha256': mock.ANY}
+                'owner_specified.shade.sha256': mock.ANY,
+                'visibility': 'private'}
         glance_mock.images.create.assert_called_with(**args)
         glance_mock.images.upload.assert_called_with(
-            image_data=mock.ANY, image_id=fake_image.id, image_size=1)
+            image_data=mock.ANY, image_id=fake_image.id)
         fake_image_dict = meta.obj_to_dict(fake_image)
         self.assertEqual([fake_image_dict], self.cloud.list_images())
 
@@ -374,7 +381,8 @@ class TestMemoryCache(base.TestCase):
             'image_properties': {'name': '99 name'}})
         args = {'owner_specified.shade.md5': fake_md5,
                 'owner_specified.shade.sha256': fake_sha256,
-                'image_id': '99'}
+                'image_id': '99',
+                'visibility': 'private'}
         glance_mock.images.update.assert_called_with(**args)
         fake_image_dict = meta.obj_to_dict(fake_image)
         self.assertEqual([fake_image_dict], self.cloud.list_images())
@@ -399,3 +407,42 @@ class TestMemoryCache(base.TestCase):
         self.cloud.list_images.invalidate(self.cloud)
         self.assertEqual(
             [fi, fi2], [dict(x) for x in self.cloud.list_images()])
+
+
+class TestBogusAuth(base.TestCase):
+    CONFIG = {
+        'clouds':
+        {
+            '_bogus_test_':
+            {
+                'auth_type': 'bogus',
+                'auth':
+                {
+                    'auth_url': 'http://198.51.100.1:35357/v2.0',
+                    'username': '_test_user_',
+                    'password': '_test_pass_',
+                    'project_name': '_test_project_',
+                },
+                'region_name': '_test_region_',
+            },
+        },
+    }
+
+    def setUp(self):
+        super(TestBogusAuth, self).setUp()
+
+        # Isolate os-client-config from test environment
+        config = tempfile.NamedTemporaryFile(delete=False)
+        config.write(bytes(yaml.dump(self.CONFIG).encode('utf-8')))
+        config.close()
+        vendor = tempfile.NamedTemporaryFile(delete=False)
+        vendor.write(b'{}')
+        vendor.close()
+
+        self.cloud_config = occ.OpenStackConfig(config_files=[config.name],
+                                                vendor_files=[vendor.name])
+
+    def test_get_auth_bogus(self):
+        with testtools.ExpectedException(exc.OpenStackCloudException):
+            shade.openstack_cloud(
+                cloud='_bogus_test_', config=self.cloud_config)
