@@ -40,7 +40,8 @@ class TestCloudEndpoints(base.TestCase):
     def setUp(self):
         super(TestCloudEndpoints, self).setUp()
         config = os_client_config.OpenStackConfig()
-        self.client = OperatorCloud(cloud_config=config.get_one_cloud())
+        self.client = OperatorCloud(
+            cloud_config=config.get_one_cloud(validate=False))
         self.mock_ks_endpoints = \
             [FakeEndpoint(**kwa) for kwa in self.mock_endpoints]
 
